@@ -41,9 +41,11 @@ def file_paths_from_folder(
                     lower_file_name = file_name.lower()
 
                     if allowed_extensions:
+                        should_add = False
+
                         for allowed_extension in allowed_extensions:
-                            if not lower_file_name.endswith(allowed_extension):
-                                should_add = False
+                            if lower_file_name.endswith(allowed_extension):
+                                should_add = True
 
                                 break
                     
